@@ -51,6 +51,7 @@ class EdgeFunction(
         runtime: aws_cdk.aws_lambda.Runtime,
         allow_all_outbound: typing.Optional[builtins.bool] = None,
         allow_public_subnet: typing.Optional[builtins.bool] = None,
+        code_signing_config: typing.Optional[aws_cdk.aws_lambda.ICodeSigningConfig] = None,
         current_version_options: typing.Optional[aws_cdk.aws_lambda.VersionOptions] = None,
         dead_letter_queue: typing.Optional[aws_cdk.aws_sqs.IQueue] = None,
         dead_letter_queue_enabled: typing.Optional[builtins.bool] = None,
@@ -90,6 +91,7 @@ class EdgeFunction(
         :param runtime: The runtime environment for the Lambda function that you are uploading. For valid values, see the Runtime property in the AWS Lambda Developer Guide. Use ``Runtime.FROM_IMAGE`` when when defining a function from a Docker image.
         :param allow_all_outbound: Whether to allow the Lambda to send all network traffic. If set to false, you must individually add traffic rules to allow the Lambda to connect to network targets. Default: true
         :param allow_public_subnet: Lambda Functions in a public subnet can NOT access the internet. Use this property to acknowledge this limitation and still place the function in a public subnet. Default: false
+        :param code_signing_config: Code signing config associated with this function. Default: - Not Sign the Code
         :param current_version_options: Options for the ``lambda.Version`` resource automatically created by the ``fn.currentVersion`` method. Default: - default options as described in ``VersionOptions``
         :param dead_letter_queue: The SQS queue to use if DLQ is enabled. Default: - SQS queue with 14 day retention period if ``deadLetterQueueEnabled`` is ``true``
         :param dead_letter_queue_enabled: Enabled DLQ. If ``deadLetterQueue`` is undefined, an SQS queue with default options will be defined for your Function. Default: - false unless ``deadLetterQueue`` is set, which implies DLQ is enabled.
@@ -129,6 +131,7 @@ class EdgeFunction(
             runtime=runtime,
             allow_all_outbound=allow_all_outbound,
             allow_public_subnet=allow_public_subnet,
+            code_signing_config=code_signing_config,
             current_version_options=current_version_options,
             dead_letter_queue=dead_letter_queue,
             dead_letter_queue_enabled=dead_letter_queue_enabled,
@@ -691,6 +694,7 @@ class EdgeFunction(
         "retry_attempts": "retryAttempts",
         "allow_all_outbound": "allowAllOutbound",
         "allow_public_subnet": "allowPublicSubnet",
+        "code_signing_config": "codeSigningConfig",
         "current_version_options": "currentVersionOptions",
         "dead_letter_queue": "deadLetterQueue",
         "dead_letter_queue_enabled": "deadLetterQueueEnabled",
@@ -732,6 +736,7 @@ class EdgeFunctionProps(aws_cdk.aws_lambda.FunctionProps):
         retry_attempts: typing.Optional[jsii.Number] = None,
         allow_all_outbound: typing.Optional[builtins.bool] = None,
         allow_public_subnet: typing.Optional[builtins.bool] = None,
+        code_signing_config: typing.Optional[aws_cdk.aws_lambda.ICodeSigningConfig] = None,
         current_version_options: typing.Optional[aws_cdk.aws_lambda.VersionOptions] = None,
         dead_letter_queue: typing.Optional[aws_cdk.aws_sqs.IQueue] = None,
         dead_letter_queue_enabled: typing.Optional[builtins.bool] = None,
@@ -770,6 +775,7 @@ class EdgeFunctionProps(aws_cdk.aws_lambda.FunctionProps):
         :param retry_attempts: The maximum number of times to retry when the function returns an error. Minimum: 0 Maximum: 2 Default: 2
         :param allow_all_outbound: Whether to allow the Lambda to send all network traffic. If set to false, you must individually add traffic rules to allow the Lambda to connect to network targets. Default: true
         :param allow_public_subnet: Lambda Functions in a public subnet can NOT access the internet. Use this property to acknowledge this limitation and still place the function in a public subnet. Default: false
+        :param code_signing_config: Code signing config associated with this function. Default: - Not Sign the Code
         :param current_version_options: Options for the ``lambda.Version`` resource automatically created by the ``fn.currentVersion`` method. Default: - default options as described in ``VersionOptions``
         :param dead_letter_queue: The SQS queue to use if DLQ is enabled. Default: - SQS queue with 14 day retention period if ``deadLetterQueueEnabled`` is ``true``
         :param dead_letter_queue_enabled: Enabled DLQ. If ``deadLetterQueue`` is undefined, an SQS queue with default options will be defined for your Function. Default: - false unless ``deadLetterQueue`` is set, which implies DLQ is enabled.
@@ -825,6 +831,8 @@ class EdgeFunctionProps(aws_cdk.aws_lambda.FunctionProps):
             self._values["allow_all_outbound"] = allow_all_outbound
         if allow_public_subnet is not None:
             self._values["allow_public_subnet"] = allow_public_subnet
+        if code_signing_config is not None:
+            self._values["code_signing_config"] = code_signing_config
         if current_version_options is not None:
             self._values["current_version_options"] = current_version_options
         if dead_letter_queue is not None:
@@ -945,6 +953,17 @@ class EdgeFunctionProps(aws_cdk.aws_lambda.FunctionProps):
         result = self._values.get("allow_public_subnet")
         return typing.cast(typing.Optional[builtins.bool], result)
 
+    @builtins.property
+    def code_signing_config(
+        self,
+    ) -> typing.Optional[aws_cdk.aws_lambda.ICodeSigningConfig]:
+        '''Code signing config associated with this function.
+
+        :default: - Not Sign the Code
+        '''
+        result = self._values.get("code_signing_config")
+        return typing.cast(typing.Optional[aws_cdk.aws_lambda.ICodeSigningConfig], result)
+
     @builtins.property
     def current_version_options(
         self,
